==> ugene_1.12.3+dfsg.orig.tar.xz: ugene-1.12.3+dfsg.orig/src/ugeneui/src/task_view/TaskStatusBar.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _TASK_STATUS_BAR_H_
#define _TASK_STATUS_BAR_H_

#include <U2Core/Task.h>
#include <U2Gui/Notification.h>
#include <U2Core/Log.h>

#include <QtGui/QWidget>
#include <QtGui/QLabel>
#include <QtGui/QProgressBar>
#include <QtGui/QPixmap>
#include <QtGui/QHBoxLayout>

namespace U2 {

class MainWindowImpl;

class TaskStatusBar : public QWidget {
    Q_OBJECT

public:
    TaskStatusBar();

private slots:
    void sl_taskStateChanged(Task* t);
    void sl_taskStateChanged();
    void sl_taskProgressChanged();
    void sl_taskDescChanged();
    void sl_reportsCountChanged();
    void sl_newReport(Task*);

    void sl_showReport();
    void sl_notificationChanged();

protected:
    bool eventFilter(QObject *o, QEvent *e);
    void mouseDoubleClickEvent(QMouseEvent *e);
    void drawProgress(QLabel* l);
    
private:
    void updateState();
    void setTaskToTrack(Task* t);

    Task*           taskToTrack;
    QHBoxLayout*    l;
    QLabel*         taskInfoLabel;
    QProgressBar*   taskProgressBar;
    QLabel*         taskCountLabel;
    QLabel*         lampLabel;
    QLabel*         notificationLabel;
    QPixmap         iconOn;
    QPixmap         iconOff;
    int             nReports;
    bool            tvConnected;
    NotificationStack*   nStack;  
    QPixmap         notificationEmpty;
    QPixmap         notificationReport;
    QPixmap         notificationError;
};


}//namespace

#endif

==> ugene_1.25.0+dfsg.orig.tar.xz: ugene-1.25.0/src/ugeneui/src/task_view/TaskStatusBar.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _TASK_STATUS_BAR_H_
#define _TASK_STATUS_BAR_H_

#include <U2Core/Task.h>
#include <U2Gui/Notification.h>
#include <U2Core/Log.h>

#if (QT_VERSION < 0x050000) //Qt 5
#include <QtGui/QWidget>
#include <QtGui/QLabel>
#include <QtGui/QProgressBar>
#include <QtGui/QHBoxLayout>
#else
#include <QtWidgets/QWidget>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QHBoxLayout>
#endif

#include <QtGui/QPixmap>

namespace U2 {

class MainWindowImpl;

class TaskStatusBar : public QWidget {
    Q_OBJECT

public:
    TaskStatusBar();

private slots:
    void sl_taskStateChanged(Task* t);
    void sl_taskStateChanged();
    void sl_taskProgressChanged();
    void sl_taskDescChanged();
    void sl_reportsCountChanged();
    void sl_newReport(Task*);

    void sl_showReport();
    void sl_notificationChanged();

protected:
    bool eventFilter(QObject *o, QEvent *e);
    void mouseDoubleClickEvent(QMouseEvent *e);
    void drawProgress(QLabel* l);
    
private:
    void updateState();
    void setTaskToTrack(Task* t);

    Task*           taskToTrack;
    QHBoxLayout*    l;
    QLabel*         taskInfoLabel;
    QProgressBar*   taskProgressBar;
    QLabel*         taskCountLabel;
    QLabel*         lampLabel;
    QLabel*         notificationLabel;
    QPixmap         iconOn;
    QPixmap         iconOff;
    int             nReports;
    bool            tvConnected;
    NotificationStack*   nStack;  
    QPixmap         notificationEmpty;
    QPixmap         notificationReport;
    QPixmap         notificationError;
};


}//namespace

#endif
